@@ -48,7 +48,7 @@ import os
 
 import ctypes
 import weakref
-import array
+# import array
 import itertools
 import textwrap
 import struct
@@ -66,7 +66,9 @@ if _IS_PYTHON3:  # some type lists to use with isinstance
     _NUMTYPES = (int, float)
     _STRTYPES = (str, bytes)
 else:
+    # noinspection PyUnresolvedReferences
     _INTTYPES = (int, long)
+    # noinspection PyUnresolvedReferences
     _NUMTYPES = (int, long, float)
     _STRTYPES = (str,)
 
@@ -151,7 +153,7 @@ def _is_color(color):
 #        return 3
 
 # Format the color to ctypes, will preserve None and False
-_formatColor = _Color.new
+_format_color = _Color.new
 
 
 def _get_image_size(filename):
@@ -190,12 +192,13 @@ class _MetaConsole(object):
 
     def __init__(self):
         self._cursor = (0, 0)
-        self._scrollMode = 'error'
-        self._fgcolor = _formatColor((255, 255, 255))
-        self._bgcolor = _formatColor((0, 0, 0))
+        self._scroll_mode = 'error'
+        self._fgcolor = _format_color((255, 255, 255))
+        self._bgcolor = _format_color((0, 0, 0))
         self._bgblend = 1  # SET
         self._colorLock = None  # which object sets the ctype color options
 
+    # noinspection PyUnresolvedReferences
     def _normalize_point(self, x, y):
         """Check if a point is in bounds and make minor adjustments.
         
@@ -218,6 +221,7 @@ class _MetaConsole(object):
             y += self.height
         return x, y
 
+    # noinspection PyUnresolvedReferences
     def _normalize_rect(self, x, y, width, height):
         """Check if the rectangle is in bounds and make minor adjustments.
         raise AssertionError's for any problems
@@ -254,15 +258,16 @@ class _MetaConsole(object):
             x -= width
             y += 1
         while y >= height:
-            if self._scrollMode == 'scroll':
+            if self._scroll_mode == 'scroll':
                 y -= 1
                 self.scroll(0, -1)
-            elif self._scrollMode == 'error':
+            elif self._scroll_mode == 'error':
                 # reset the cursor on error
                 self._cursor = (0, 0)
                 raise TDLError('Cursor has reached the end of the console')
         return x, y
 
+    # noinspection PyUnresolvedReferences
     def _lock_colors(self, force_update=False):
         """Make sure the color options on the root console match ths instance"""
         if self.console._lock_colors is not self or force_update:
@@ -295,8 +300,9 @@ class _MetaConsole(object):
         modes = ['error', 'scroll']
         if mode.lower() not in modes:
             raise TDLError('mode must be one of %s, got %s' % (modes, repr(mode)))
-        self._scrollMode = mode.lower()
+        self._scroll_mode = mode.lower()
 
+    # noinspection PyUnresolvedReferences
     def set_colors(self, fg=None, bg=None):
         """Sets the colors to be used with the L{print_str} function.
         
@@ -305,9 +311,9 @@ class _MetaConsole(object):
         if self.console._lock_colors is self:
             self.console._lock_colors = None
         if fg is not None:
-            self._fgcolor = _formatColor(fg)
+            self._fgcolor = _format_color(fg)
         if bg is not None:
-            self._bgcolor = _formatColor(bg)
+            self._bgcolor = _format_color(bg)
 
     def print_str(self, string):
         """Print a string at the virtual cursor.
@@ -368,6 +374,7 @@ class _MetaConsole(object):
         y -= 1
         self._cursor = (x, y)
 
+    # noinspection PyUnresolvedReferences
     def draw_char(self, x, y, char, fgcolor=(255, 255, 255), bgcolor=(0, 0, 0)):
         """Draws a single character.
 
@@ -399,9 +406,10 @@ class _MetaConsole(object):
         assert _verify_colors(fgcolor, bgcolor)
         x, y = self._normalize_point(x, y)
         x, y = ctypes.c_int(x), ctypes.c_int(y)
-        self._setChar(x, y, _format_char(char),
-                      _formatColor(fgcolor), _formatColor(bgcolor))
+        self._set_char(x, y, _format_char(char),
+                       _format_color(fgcolor), _format_color(bgcolor))
 
+    # noinspection PyUnresolvedReferences
     def draw_str(self, x, y, string, fgcolor=(255, 255, 255), bgcolor=(0, 0, 0)):
         """Draws a string starting at x and y.  Optionally colored.
 
@@ -445,7 +453,7 @@ class _MetaConsole(object):
 
         x, y = self._normalize_point(x, y)
         assert _verify_colors(fgcolor, bgcolor)
-        fgcolor, bgcolor = _formatColor(fgcolor), _formatColor(bgcolor)
+        fgcolor, bgcolor = _format_color(fgcolor), _format_color(bgcolor)
         width, height = self.get_size()
         #batch = []  # prepare a batch operation
 
@@ -466,8 +474,9 @@ class _MetaConsole(object):
                     x = 0
                     y += 1
 
-        self._setCharBatch(_draw_str_gen(), fgcolor, bgcolor)
+        self._set_char_batch(_draw_str_gen(), fgcolor, bgcolor)
 
+    # noinspection PyUnresolvedReferences
     def draw_rect(self, x, y, width, height, string, fgcolor=(255, 255, 255), bgcolor=(0, 0, 0)):
         """Draws a rectangle starting from x and y and extending to width and height.
         
@@ -509,7 +518,7 @@ class _MetaConsole(object):
         """
         x, y, width, height = self._normalize_rect(x, y, width, height)
         assert _verify_colors(fgcolor, bgcolor)
-        fgcolor, bgcolor = _formatColor(fgcolor), _formatColor(bgcolor)
+        fgcolor, bgcolor = _format_color(fgcolor), _format_color(bgcolor)
         char = _format_char(string)
         # use itertools to make an x,y grid
         # using ctypes here reduces type converstions later
@@ -517,7 +526,7 @@ class _MetaConsole(object):
                                  (ctypes.c_int(y) for y in range(y, y + height)))
         # zip the single character in a batch variable
         batch = zip(grid, itertools.repeat(char, width * height))
-        self._setCharBatch(batch, fgcolor, bgcolor, nullChar=(char is None))
+        self._set_char_batch(batch, fgcolor, bgcolor, nullChar=(char is None))
 
     def draw_frame(self, x, y, width, height, string, fgcolor=(255, 255, 255), bgcolor=(0, 0, 0)):
         """Similar to L{draw_rect} but only draws the outline of the rectangle.
@@ -558,7 +567,7 @@ class _MetaConsole(object):
         """
         x, y, width, height = self._normalize_rect(x, y, width, height)
         assert _verify_colors(fgcolor, bgcolor)
-        fgcolor, bgcolor = _formatColor(fgcolor), _formatColor(bgcolor)
+        fgcolor, bgcolor = _format_color(fgcolor), _format_color(bgcolor)
         char = _format_char(string)
         if width == 1 or height == 1:  # it's just a single width line here
             return self.draw_rect(x, y, width, height, char, fgcolor, bgcolor)
@@ -569,7 +578,7 @@ class _MetaConsole(object):
         self.draw_rect(x + width - 1, y, 1, height, char, fgcolor, bgcolor)
         self.draw_rect(x, y + height - 1, width, 1, char, fgcolor, bgcolor)
 
-    # noinspection PyProtectedMember
+    # noinspection PyProtectedMember,PyUnresolvedReferences
     def blit(self, source, x=0, y=0, width=None, height=None, src_x=0, src_y=0):
         """Blit another console or Window onto the current console.
 
@@ -628,6 +637,7 @@ class _MetaConsole(object):
         else:
             _lib.TCOD_console_blit(source, src_x, src_y, width, height, self, x, y, fg_alpha, bg_alpha)
 
+    # noinspection PyUnresolvedReferences
     def get_cursor(self):
         """Return the virtual cursor position.
         
@@ -641,10 +651,11 @@ class _MetaConsole(object):
         while x >= width:
             x -= width
             y += 1
-        if y >= height and self.scrollMode == 'scroll':
+        if y >= height and self.scroll_mode == 'scroll':
             y = height - 1
         return x, y
 
+    # noinspection PyUnresolvedReferences
     def get_size(self):
         """Return the size of the console as (width, height)
 
@@ -652,6 +663,7 @@ class _MetaConsole(object):
         """
         return self.width, self.height
 
+    # noinspection PyUnresolvedReferences
     def __iter__(self):
         """Return an iterator with every possible (x, y) value for this console.
         
@@ -671,7 +683,7 @@ class _MetaConsole(object):
         """
         self._cursor = self._normalize_point(x, y)
 
-    # noinspection PyTypeChecker
+    # noinspection PyTypeChecker,PyUnresolvedReferences
     def scroll(self, x, y):
         """Scroll the contents of the console in the direction of x,y.
 
@@ -756,6 +768,7 @@ class _MetaConsole(object):
         """
         raise NotImplementedError('Method here only exists for the docstring')
 
+    # noinspection PyUnresolvedReferences
     def __contains__(self, position):
         """Use ((x, y) in console) to check if a position is drawable on this console.
         """
@@ -817,7 +830,7 @@ class Console(_MetaConsole):
                 _root_initialized = False
                 _rootConsoleRef = None
             _lib.TCOD_console_delete(self)
-        except StandardError:
+        except TDLError:
             pass  # I forget why I put this here but I'm to afraid to delete it
 
     def __copy__(self):
@@ -878,8 +891,8 @@ class Console(_MetaConsole):
         assert _verify_colors(fgcolor, bgcolor)
         assert fgcolor and bgcolor, 'Can not use None with clear'
         self._typewriter = None
-        _lib.TCOD_console_set_default_background(self, _formatColor(bgcolor))
-        _lib.TCOD_console_set_default_foreground(self, _formatColor(fgcolor))
+        _lib.TCOD_console_set_default_background(self, _format_color(bgcolor))
+        _lib.TCOD_console_set_default_foreground(self, _format_color(fgcolor))
         _lib.TCOD_console_clear(self)
 
     def _set_char(self, x, y, char, fgcolor=None, bgcolor=None, bgblend=1):
@@ -889,7 +902,7 @@ class Console(_MetaConsole):
 
         Because of the need for speed this function will do NO TYPE CHECKING
         AT ALL, it's up to the drawing functions to use the functions:
-        _format_char and _formatColor before passing to this."""
+        _format_char and _format_color before passing to this."""
         # buffer values as ctypes objects
         console = self._as_parameter_
 
@@ -1342,6 +1355,7 @@ def screenshot(path=None):
         tmp_name = os.tempnam()
         _lib.TCOD_sys_save_screenshot(_encode_string(tmp_name))
         with tmp_name as tmp_file:
+            # noinspection PyUnresolvedReferences
             path.write(tmp_file.read())
         os.remove(tmp_name)
         #else:
